documentFactory.MarcDocumentStream

|  | ## Cheshire3 Object Model: Class MarcDocumentStream

Module documentFactory :: Class MarcDocumentStream

## Class MarcDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
                        MarcDocumentStream

Instance Methods

find_documents(self, session, cache=0)
Inherited from `BaseDocumentStream`: `__init__`, `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### find_documents(self, session, cache=0) | source code